@@ -17,7 +17,7 @@ limitations under the License.
 package controller
 
 import (
-	"github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/controller/helmrelease"
+	"github.com/stolostron/multicloud-operators-subscription-release/pkg/controller/helmrelease"
 )
 
 func init() {
