@@ -29,8 +29,8 @@ import (
 	"helm.sh/helm/v3/pkg/chart/loader"
 	"helm.sh/helm/v3/pkg/storage"
 
-	helmclient "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/client"
-	helmoperator "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/release"
+	helmclient "github.com/stolostron/multicloud-operators-subscription-release/pkg/client"
+	helmoperator "github.com/stolostron/multicloud-operators-subscription-release/pkg/release"
 	"helm.sh/helm/v3/pkg/action"
 	"helm.sh/helm/v3/pkg/kube"
 	"helm.sh/helm/v3/pkg/storage/driver"
@@ -41,8 +41,8 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/manager"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 
-	appv1 "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
-	"github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/utils"
+	appv1 "github.com/stolostron/multicloud-operators-subscription-release/pkg/apis/apps/v1"
+	"github.com/stolostron/multicloud-operators-subscription-release/pkg/utils"
 )
 
 //newHelmOperatorManagerFactory create a new manager returns a helmManagerFactory
