@@ -17,20 +17,29 @@ limitations under the License.
 package utils
 
 import (
+	"bytes"
 	"crypto/tls"
+	"crypto/x509"
+	"encoding/pem"
 	"fmt"
 	"io"
+	"io/ioutil"
 	"net"
 	"net/http"
 	"net/url"
 	"os"
+	"os/exec"
 	"path/filepath"
 	"strconv"
 	"strings"
 	"time"
 
+	gitssh "github.com/go-git/go-git/v5/plumbing/transport/ssh"
+	"golang.org/x/crypto/ssh"
+	"golang.org/x/crypto/ssh/knownhosts"
 	"gopkg.in/src-d/go-git.v4"
 	"gopkg.in/src-d/go-git.v4/plumbing"
+	gitclient "gopkg.in/src-d/go-git.v4/plumbing/transport/client"
 	githttp "gopkg.in/src-d/go-git.v4/plumbing/transport/http"
 	"helm.sh/helm/v3/pkg/chartutil"
 	corev1 "k8s.io/api/core/v1"
@@ -38,11 +47,12 @@ import (
 	"k8s.io/client-go/rest"
 	"k8s.io/klog"
 
-	appv1 "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
+	appv1 "github.com/stolostron/multicloud-operators-subscription-release/pkg/apis/apps/v1"
 )
 
 //GetHelmRepoClient returns an *http.client to access the helm repo
-func GetHelmRepoClient(parentNamespace string, configMap *corev1.ConfigMap) (rest.HTTPClient, error) {
+func GetHelmRepoClient(parentNamespace string, configMap *corev1.ConfigMap, skipCertVerify bool) (rest.HTTPClient, error) {
+	/* #nosec G402 */
 	transport := &http.Transport{
 		Proxy: http.ProxyFromEnvironment,
 		DialContext: (&net.Dialer{
@@ -55,11 +65,15 @@ func GetHelmRepoClient(parentNamespace string, configMap *corev1.ConfigMap) (res
 		TLSHandshakeTimeout:   10 * time.Second,
 		ExpectContinueTimeout: 1 * time.Second,
 		TLSClientConfig: &tls.Config{
-			InsecureSkipVerify: false,
+			InsecureSkipVerify: skipCertVerify, // #nosec G402 InsecureSkipVerify conditionally
 			MinVersion:         tls.VersionTLS12,
 		},
 	}
 
+	if skipCertVerify {
+		klog.Info("repo.insecureSkipVerify=true. Skipping repo server's certificate verification.")
+	}
+
 	if configMap != nil {
 		configData := configMap.Data
 		klog.V(5).Info("ConfigRef retrieved :", configData)
@@ -77,7 +91,7 @@ func GetHelmRepoClient(parentNamespace string, configMap *corev1.ConfigMap) (res
 				return nil, err
 			}
 
-			klog.V(5).Info("Set InsecureSkipVerify: ", b)
+			klog.Info("From config map, seting InsecureSkipVerify: ", b)
 			transport.TLSClientConfig.InsecureSkipVerify = b
 		} else {
 			klog.V(5).Info("insecureSkipVerify is not specified")
@@ -127,9 +141,9 @@ func DownloadChartFromGit(configMap *corev1.ConfigMap, secret *corev1.Secret, de
 	}
 
 	if s.Repo.Source.GitHub != nil {
-		_, err = DownloadGitRepo(configMap, secret, destRepo, s.Repo.Source.GitHub.Urls, s.Repo.Source.GitHub.Branch)
+		_, err = DownloadGitRepo(configMap, secret, destRepo, s.Repo.Source.GitHub.Urls, s.Repo.Source.GitHub.Branch, s.Repo.InsecureSkipVerify)
 	} else if s.Repo.Source.Git != nil {
-		_, err = DownloadGitRepo(configMap, secret, destRepo, s.Repo.Source.Git.Urls, s.Repo.Source.Git.Branch)
+		_, err = DownloadGitRepo(configMap, secret, destRepo, s.Repo.Source.Git.Urls, s.Repo.Source.Git.Branch, s.Repo.InsecureSkipVerify)
 	}
 
 	if err != nil {
@@ -149,7 +163,8 @@ func DownloadChartFromGit(configMap *corev1.ConfigMap, secret *corev1.Secret, de
 func DownloadGitRepo(configMap *corev1.ConfigMap,
 	secret *corev1.Secret,
 	destRepo string,
-	urls []string, branch string) (commitID string, err error) {
+	urls []string, branch string,
+	insecureSkipVerify bool) (commitID string, err error) {
 	for _, url := range urls {
 		options := &git.CloneOptions{
 			URL:               url,
@@ -178,6 +193,54 @@ func DownloadGitRepo(configMap *corev1.ConfigMap,
 			klog.Error(err, "- Failed to remove all: ", destRepo)
 		}
 
+		err = os.MkdirAll(destRepo, os.ModePerm)
+		if err != nil {
+			return "", err
+		}
+
+		if strings.HasPrefix(url, "http") {
+			klog.Info("Connecting to Git server via HTTP")
+
+			caCert := ""
+
+			if configMap != nil {
+				caCert = configMap.Data["caCerts"]
+			}
+
+			err := getHTTPOptions(options, caCert, insecureSkipVerify)
+
+			if err != nil {
+				klog.Error(err, "failed to prepare HTTP clone options")
+				return "", err
+			}
+		} else {
+			klog.Info("Connecting to Git server via SSH")
+
+			knownhostsfile := filepath.Join(destRepo, "known_hosts")
+
+			if !insecureSkipVerify {
+				err := getKnownHostFromURL(url, knownhostsfile)
+
+				if err != nil {
+					return "", err
+				}
+			}
+
+			sshKey := []byte("")
+			passphrase := []byte("")
+
+			if secret != nil {
+				sshKey = bytes.TrimSpace(secret.Data["sshKey"])
+				passphrase = bytes.TrimSpace(secret.Data["passphrase"])
+			}
+
+			err = getSSHOptions(options, sshKey, passphrase, knownhostsfile, insecureSkipVerify)
+			if err != nil {
+				klog.Error(err, " failed to prepare SSH clone options")
+				return "", err
+			}
+		}
+
 		r, errClone := git.PlainClone(destRepo, false, options)
 
 		if errClone != nil {
@@ -217,6 +280,218 @@ func DownloadGitRepo(configMap *corev1.ConfigMap,
 	return commitID, err
 }
 
+func getCertChain(certs string) tls.Certificate {
+	var certChain tls.Certificate
+
+	certPEMBlock := []byte(certs)
+
+	var certDERBlock *pem.Block
+
+	for {
+		certDERBlock, certPEMBlock = pem.Decode(certPEMBlock)
+
+		if certDERBlock == nil {
+			break
+		}
+
+		if certDERBlock.Type == "CERTIFICATE" {
+			certChain.Certificate = append(certChain.Certificate, certDERBlock.Bytes)
+		}
+	}
+
+	return certChain
+}
+
+func getKnownHostFromURL(sshURL string, filepath string) error {
+	sshhostname := ""
+	sshhostport := ""
+
+	if strings.HasPrefix(sshURL, "ssh:") {
+		u, err := url.Parse(sshURL)
+
+		if err != nil {
+			klog.Error("failed toparse SSH URL: ", err)
+			return err
+		}
+
+		sshhostname = strings.Split(u.Host, ":")[0]
+
+		sshhostport = u.Host
+	} else if strings.HasPrefix(sshURL, "git@") {
+		sshhostname = strings.Split(strings.SplitAfter(sshURL, "@")[1], ":")[0]
+	}
+
+	klog.Info("Getting public SSH host key for " + sshhostname)
+
+	cmd := exec.Command("ssh-keyscan", sshhostname) // #nosec G204 the variable is generated within this function.
+	stdout, err := cmd.Output()
+
+	if err != nil {
+		klog.Error("failed to get public SSH host key: ", err)
+
+		if sshhostport != "" && (sshhostport != sshhostname) {
+			klog.Info("Getting public SSH host key for " + sshhostport)
+
+			cmd2 := exec.Command("ssh-keyscan", sshhostport) // #nosec G204 the variable is generated within this function.
+			stdout2, err2 := cmd2.Output()
+
+			if err2 != nil {
+				klog.Error("failed to get public SSH host key: ", err2)
+				return err2
+			}
+
+			stdout = stdout2
+		} else {
+			return err
+		}
+	}
+
+	klog.Info("SSH host key: " + string(stdout))
+
+	if err := ioutil.WriteFile(filepath, stdout, 0600); err != nil {
+		klog.Error("failed to write known_hosts file: ", err)
+		return err
+	}
+
+	return nil
+}
+
+func getSSHOptions(options *git.CloneOptions, sshKey, passphrase []byte, knownhostsfile string, insecureSkipVerify bool) error {
+	publicKey := &gitssh.PublicKeys{}
+	publicKey.User = "git"
+
+	if len(passphrase) > 0 {
+		klog.Info("Parsing SSH private key with passphrase")
+
+		signer, err := ssh.ParsePrivateKeyWithPassphrase(sshKey, passphrase)
+
+		if err != nil {
+			klog.Error("failed to parse SSH key", err.Error())
+			return err
+		}
+
+		publicKey.Signer = signer
+	} else {
+		signer, err := ssh.ParsePrivateKey(sshKey)
+		if err != nil {
+			klog.Error("failed to parse SSH key", err.Error())
+			return err
+		}
+		publicKey.Signer = signer
+	}
+
+	if insecureSkipVerify {
+		klog.Info("Insecure ignore SSH host key")
+
+		publicKey.HostKeyCallback = ssh.InsecureIgnoreHostKey() // #nosec G106 this is optional and used only if users specify it in channel configuration
+	} else {
+		klog.Info("Using SSH known host keys")
+		callback, err := knownhosts.New(knownhostsfile)
+
+		if err != nil {
+			klog.Error("failed to get knownhosts ", err)
+			return err
+		}
+
+		publicKey.HostKeyCallback = callback
+	}
+
+	options.Auth = publicKey
+
+	return nil
+}
+
+func getHTTPOptions(options *git.CloneOptions, caCerts string, insecureSkipVerify bool) error {
+	installProtocol := false
+
+	clientConfig := &tls.Config{MinVersion: tls.VersionTLS12}
+
+	// skip TLS certificate verification for Git servers with custom or self-signed certs
+	if insecureSkipVerify {
+		klog.Info("insecureSkipVerify = true, skipping Git server's certificate verification.")
+
+		clientConfig.InsecureSkipVerify = true
+
+		installProtocol = true
+	} else if !strings.EqualFold(caCerts, "") {
+		klog.Info("Adding Git server's CA certificate to trust certificate pool")
+
+		// Load the host's trusted certs into memory
+		certPool, _ := x509.SystemCertPool()
+		if certPool == nil {
+			certPool = x509.NewCertPool()
+		}
+
+		certChain := getCertChain(caCerts)
+
+		if len(certChain.Certificate) == 0 {
+			klog.Warning("No certificate found")
+		}
+
+		// Add CA certs from the channel config map to the cert pool
+		// It will not add duplicate certs
+		for _, cert := range certChain.Certificate {
+			x509Cert, err := x509.ParseCertificate(cert)
+			if err != nil {
+				return err
+			}
+			klog.Info("Adding certificate -->" + x509Cert.Subject.String())
+			certPool.AddCert(x509Cert)
+		}
+
+		clientConfig.RootCAs = certPool
+
+		installProtocol = true
+	}
+
+	if installProtocol {
+		klog.Info("HTTP_PROXY = " + os.Getenv("HTTP_PROXY"))
+		klog.Info("HTTPS_PROXY = " + os.Getenv("HTTPS_PROXY"))
+
+		transportConfig := &http.Transport{
+			/* #nosec G402 */
+			TLSClientConfig: clientConfig,
+		}
+
+		proxyURLEnv := ""
+
+		if os.Getenv("HTTPS_PROXY") != "" {
+			proxyURLEnv = os.Getenv("HTTPS_PROXY")
+		} else if os.Getenv("HTTP_PROXY") != "" {
+			proxyURLEnv = os.Getenv("HTTP_PROXY")
+		}
+
+		if proxyURLEnv != "" {
+			proxyURL, err := url.Parse(proxyURLEnv)
+
+			if err != nil {
+				klog.Error(err.Error())
+				return err
+			}
+
+			transportConfig.Proxy = http.ProxyURL(proxyURL)
+
+			klog.Info("setting HTTP transport proxy to " + proxyURLEnv)
+		}
+
+		customClient := &http.Client{
+			/* #nosec G402 */
+			Transport: transportConfig,
+
+			// 15 second timeout
+			Timeout: 15 * time.Second,
+
+			CheckRedirect: func(req *http.Request, via []*http.Request) error {
+				return http.ErrUseLastResponse
+			},
+		}
+
+		gitclient.InstallProtocol("https", githttp.NewClient(customClient))
+	}
+
+	return nil
+}
+
 //DownloadChartFromHelmRepo downloads a chart into the chartDir
 func DownloadChartFromHelmRepo(configMap *corev1.ConfigMap,
 	secret *corev1.Secret,
@@ -246,7 +521,7 @@ func downloadChartFromURL(configMap *corev1.ConfigMap,
 	destRepo string,
 	s *appv1.HelmRelease,
 	url string) (chartDir string, err error) {
-	chartZip, downloadErr := downloadFile(s.Namespace, configMap, url, secret, destRepo)
+	chartZip, downloadErr := downloadFile(s.Namespace, configMap, url, secret, destRepo, s.Repo.InsecureSkipVerify)
 	if downloadErr != nil {
 		klog.Error(downloadErr, " - url: ", url)
 		return "", downloadErr
@@ -287,7 +562,8 @@ func downloadChartFromURL(configMap *corev1.ConfigMap,
 func downloadFile(parentNamespace string, configMap *corev1.ConfigMap,
 	fileURL string,
 	secret *corev1.Secret,
-	chartsDir string) (string, error) {
+	chartsDir string,
+	insecureSkipVerify bool) (string, error) {
 	klog.V(4).Info("fileURL: ", fileURL)
 
 	URLP, downloadErr := url.Parse(fileURL)
@@ -311,7 +587,7 @@ func downloadFile(parentNamespace string, configMap *corev1.ConfigMap,
 	case "file":
 		downloadErr = downloadFileLocal(URLP, chartZip)
 	case "http", "https":
-		downloadErr = downloadFileHTTP(parentNamespace, configMap, fileURL, secret, chartZip)
+		downloadErr = downloadFileHTTP(parentNamespace, configMap, fileURL, secret, chartZip, insecureSkipVerify)
 	default:
 		downloadErr = fmt.Errorf("unsupported scheme %s", URLP.Scheme)
 	}
@@ -350,7 +626,8 @@ func downloadFileLocal(urlP *url.URL,
 func downloadFileHTTP(parentNamespace string, configMap *corev1.ConfigMap,
 	fileURL string,
 	secret *corev1.Secret,
-	chartZip string) error {
+	chartZip string,
+	insecureSkipVerify bool) error {
 	fileInfo, err := os.Stat(chartZip)
 	if fileInfo != nil && fileInfo.IsDir() {
 		downloadErr := fmt.Errorf("expecting chartZip to be a file but it's a directory: %s", chartZip)
@@ -360,7 +637,7 @@ func downloadFileHTTP(parentNamespace string, configMap *corev1.ConfigMap,
 	}
 
 	if os.IsNotExist(err) {
-		httpClient, downloadErr := GetHelmRepoClient(parentNamespace, configMap)
+		httpClient, downloadErr := GetHelmRepoClient(parentNamespace, configMap, insecureSkipVerify)
 		if downloadErr != nil {
 			klog.Error(downloadErr, " - Failed to create httpClient")
 			return downloadErr
